@@ -1,10 +1,27 @@
 import pathlib
+import typing
 
 from pwhtmltopdf.abc import BaseHTP
 from pwhtmltopdf.types import StrPath, StrPathLike
 
 
 class HtmlToPdf(BaseHTP):
+    def __init__(
+        self,
+        static_root: StrPath = None,
+        wait_until: typing.Optional[
+            typing.Literal["commit", "domcontentloaded", "load", "networkidle"]
+        ] = None,
+        print_background: typing.Optional[bool] = None,
+        prefer_css_page_size: typing.Optional[bool] = None,
+    ):
+        super().__init__(
+            static_root=static_root,
+            wait_until=wait_until,
+            print_background=print_background,
+            prefer_css_page_size=prefer_css_page_size,
+        )
+
     async def from_url(
         self,
         url: str,
